@@ -8,7 +8,7 @@ from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.test import TestCase, Client, RequestFactory
 from django.views.generic import View
-from milkman.dairy import milkman
+from mixer.backend.django import mixer
 
 from .api import API as api
 from .models import Author, Book
@@ -29,6 +29,7 @@ class MixinTest(TestCase):
         request = self.rf.get("/")
 
         class Test(View, EmitterMixin):
+
             def get(self, request):
                 content = self.emit('test')
                 response = HttpResponse(content)
@@ -45,54 +46,57 @@ class MixinTest(TestCase):
 class MetaTest(TestCase):
 
     def test_meta(self):
-        self.assertTrue(AuthorResource.meta)
-        self.assertEqual(AuthorResource.allowed_methods, (
+        self.assertTrue(AuthorResource._meta)
+        self.assertEqual(AuthorResource._meta.allowed_methods, (
             'GET', 'POST', 'PATCH', 'OPTIONS', 'HEAD'
         ))
-        self.assertEqual(AuthorResource.meta.name, 'author')
-        self.assertEqual(AuthorResource.meta.url_name, 'author')
-        self.assertEqual(AuthorResource.meta.url_regex, '^owner/$')
-        self.assertEqual(AuthorResource.meta.parents, [])
-        self.assertEqual(AuthorResource.meta.emitters_dict, {
+        self.assertEqual(AuthorResource._meta.name, 'author')
+        self.assertEqual(AuthorResource._meta.url_name, 'author')
+        self.assertEqual(AuthorResource._meta.url_regex, '^owner/$')
+        self.assertEqual(AuthorResource._meta.parents, [])
+        self.assertEqual(AuthorResource._meta.emitters_dict, {
             emitter.JSONEmitter.media_type: emitter.JSONEmitter,
         })
-        self.assertEqual(AuthorResource.meta.parsers_dict, {
+        self.assertEqual(AuthorResource._meta.parsers_dict, {
             parser.FormParser.media_type: parser.FormParser,
             parser.XMLParser.media_type: parser.XMLParser,
             parser.JSONParser.media_type: parser.JSONParser,
         })
-        self.assertEqual(AuthorResource.meta.default_parser, parser.FormParser)
+        self.assertEqual(
+            AuthorResource._meta.default_parser, parser.FormParser)
 
     def test_meta_parents(self):
-        self.assertEqual(AuthorResource.meta.parents, [])
-        self.assertEqual(BookPrefixResource.meta.parents, [AuthorResource])
-        self.assertEqual(ArticleResource.meta.parents, [
+        self.assertEqual(AuthorResource._meta.parents, [])
+        self.assertEqual(BookPrefixResource._meta.parents, [AuthorResource])
+        self.assertEqual(ArticleResource._meta.parents, [
                          AuthorResource, BookPrefixResource])
 
     def test_meta_name(self):
-        self.assertEqual(AuthorResource.meta.name, 'author')
-        self.assertEqual(BookPrefixResource.meta.name, 'book')
-        self.assertEqual(SomeOtherResource.meta.name, 'someother')
+        self.assertEqual(AuthorResource._meta.name, 'author')
+        self.assertEqual(BookPrefixResource._meta.name, 'book')
+        self.assertEqual(SomeOtherResource._meta.name, 'someother')
 
     def test_meta_url_name(self):
-        self.assertEqual(AuthorResource.meta.url_name, 'author')
-        self.assertEqual(BookResource.meta.url_name, 'author-book')
-        self.assertEqual(BookPrefixResource.meta.url_name, 'author-test-book')
+        self.assertEqual(AuthorResource._meta.url_name, 'author')
+        self.assertEqual(BookResource._meta.url_name, 'author-book')
+        self.assertEqual(BookPrefixResource._meta.url_name, 'author-test-book')
         self.assertEqual(
-            ArticleResource.meta.url_name, 'author-test-book-article')
+            ArticleResource._meta.url_name, 'author-test-book-article')
         self.assertEqual(
-            SomeOtherResource.meta.url_name, 'author-device-someother')
+            SomeOtherResource._meta.url_name, 'author-device-someother')
 
     def test_meta_url_regex(self):
-        self.assertEqual(AuthorResource.meta.url_regex, '^owner/$')
-        self.assertEqual(BookPrefixResource.meta.url_regex,
-                         'owner/test/book/(?:(?P<book>[^/]+)/)?')
+        self.assertEqual(AuthorResource._meta.url_regex, '^owner/$')
+        self.assertEqual(BookPrefixResource._meta.url_regex,
+                         'owner/test/book/(?P<book>[^/]+)?')
+
         self.assertEqual(
-            ArticleResource.meta.url_regex,
-            'owner/book/(?P<book>[^/]+)/article/(?:(?P<article>[^/]+)/)?')
+            ArticleResource._meta.url_regex,
+            'owner/test/book/(?P<book>[^/]+)?/article/(?P<article>[^/]+)?')
+
         self.assertEqual(
-            SomeOtherResource.meta.url_regex,
-            'owner/device/(?P<device>[^/]+)/someother/(?:(?P<someother>[^/]+)/)?')  # nolint
+            SomeOtherResource._meta.url_regex,
+            'owner/device/(?P<device>[^/]+)/someother/(?P<someother>[^/]+)?')
 
 
 class ApiTest(AdrestTestCase):
@@ -119,8 +123,8 @@ class AdrestTest(AdrestTestCase):
     api = api
 
     def setUp(self):
-        self.author = milkman.deliver('main.author')
-        self.book = milkman.deliver('main.book', author=self.author)
+        self.author = mixer.blend('main.author')
+        self.book = mixer.blend('main.book', author=self.author)
 
     def test_urls(self):
         uri = reverse('iamdummy')
@@ -167,12 +171,12 @@ class AdrestTest(AdrestTestCase):
             access.get().response, "Invalid response content encoding")
 
     def test_options(self):
-        self.assertTrue('OPTIONS' in ArticleResource.allowed_methods)
+        self.assertTrue('OPTIONS' in ArticleResource._meta.allowed_methods)
         uri = self.reverse('author-test-book-article', book=self.book.pk)
         response = self.client.options(uri, data=dict(author=self.author.pk))
         self.assertContains(response, 'OK')
 
-        author = milkman.deliver('main.author')
+        author = mixer.blend('main.author')
         response = self.client.options(uri, data=dict(author=author.pk))
         self.assertContains(response, 'OK')
 
@@ -344,9 +348,10 @@ class ResourceTest(AdrestTestCase):
             HTTP_AUTHORIZATION=self.author.user.accesskey_set.get().key)
         self.assertContains(response, 'Some error', status_code=500)
         # self.assertEqual(len(mail.outbox), 1)
+
         self.assertEqual(
             mail.outbox[
-            -1].subject, '[Django] ADREST API Error (500): /1.0.0/owner/book/%s/article/' % Book.objects.all().count())  # nolint
+                -1].subject, '[Django] ADREST API Error (500): /1.0.0/owner/test/book/%s/article/' % Book.objects.all().count())  # nolint
 
         response = self.client.put(
             uri, HTTP_AUTHORIZATION=self.author.user.accesskey_set.get().key)
@@ -354,7 +359,7 @@ class ResourceTest(AdrestTestCase):
         # self.assertEqual(len(mail.outbox), 2)
         self.assertEqual(
             mail.outbox[
-            -1].subject, '[Django] ADREST API Error (400): /1.0.0/owner/book/%s/article/' % Book.objects.all().count())  # nolint
+                -1].subject, '[Django] ADREST API Error (400): /1.0.0/owner/test/book/%s/article/' % Book.objects.all().count())  # nolint
 
         response = self.post_resource('book')
         self.assertContains(response, '{"error": "\'Frozen', status_code=400)
@@ -377,7 +382,7 @@ class ResourceTest(AdrestTestCase):
         self.assertTrue(response.has_header("Link"))
         self.assertEquals(
             response[
-            "Link"], '<%s?page=2&author=5>; rel="next"' % self.reverse('author-test-book'))  # nolint
+                "Link"], '<%s?page=2&author=5>; rel="next"' % self.reverse('author-test-book'))  # nolint
         # Get objects by links on Link header
         response = self.client.get(link_re.findall(response['Link'])[0][0])
 
@@ -434,4 +439,4 @@ class AdrestMapTest(TestCase):
         self.assertContains(response, '"price", {"required": false')
 
 
-# lint_ignore=F0401
+# lint_ignore=F0401,C0110
